@@ -12,7 +12,6 @@
 
 #include <QApplication>
 #include <QImage>
-#include <QMenu>
 #include <QMessageBox>
 #include <QMovie>
 #include <QPainter>
@@ -23,10 +22,6 @@
 #include <QFontDatabase>
 #endif
 
-#define slots
-#include <QtWidgets/private/qwidgetwindow_p.h>
-#undef slots
-
 #if HAVE_DBUS
 #include "kstatusnotifieritemdbus_p.h"
 
@@ -888,7 +883,7 @@ void KStatusNotifierItemPrivate::init(const QString &extraId)
     // some apps like kalarm or korgac have a hack to rewire the connection
     // of the "quit" action to a own slot, and rely on the name-based slot to disconnect
     // quitRequested/abortQuit was added for this use case
-    QObject::connect(action, SIGNAL(triggered()), q, SLOT(maybeQuit()));
+    QObject::connect(action, SIGNAL(triggered()), q, SLOT(quit()));
     actionCollection.insert(QStringLiteral("quit"), action);
 
     id = title;
@@ -1155,7 +1150,7 @@ void KStatusNotifierItem::abortQuit()
     d->quitAborted = true;
 }
 
-void KStatusNotifierItemPrivate::maybeQuit()
+void KStatusNotifierItemPrivate::quit()
 {
     Q_EMIT q->quitRequested();
 
@@ -1164,23 +1159,7 @@ void KStatusNotifierItemPrivate::maybeQuit()
         return;
     }
 
-    QString caption = QGuiApplication::applicationDisplayName();
-    if (caption.isEmpty()) {
-        caption = QCoreApplication::applicationName();
-    }
-
-    const QString title = KStatusNotifierItem::tr("Confirm Quit From System Tray", "@title:window");
-    const QString query = KStatusNotifierItem::tr("<qt>Are you sure you want to quit <b>%1</b>?</qt>").arg(caption);
-
-    auto *dialog = new QMessageBox(QMessageBox::Question, title, query, QMessageBox::NoButton);
-    dialog->setAttribute(Qt::WA_DeleteOnClose);
-
-    auto *quitButton = dialog->addButton(KStatusNotifierItem::tr("Quit", "@action:button"), QMessageBox::AcceptRole);
-    quitButton->setIcon(QIcon::fromTheme(QStringLiteral("application-exit")));
-    dialog->addButton(QMessageBox::Cancel);
-    QObject::connect(dialog, &QDialog::accepted, qApp, &QApplication::quit);
-    dialog->show();
-    dialog->windowHandle()->setTransientParent(associatedWindow);
+    qApp->quit();
 }
 
 void KStatusNotifierItemPrivate::minimizeRestore()
@@ -1214,21 +1193,11 @@ void KStatusNotifierItemPrivate::minimizeRestore(bool show)
     if (show) {
         Qt::WindowState state = (Qt::WindowState)(associatedWindow->windowState() & ~Qt::WindowMinimized);
         associatedWindow->setWindowState(state);
-        // Work around https://bugreports.qt.io/browse/QTBUG-120316
-        if (auto *widgetwindow = static_cast<QWidgetWindow*>(associatedWindow->qt_metacast("QWidgetWindow"))) {
-            widgetwindow->widget()->show();
-        } else {
-            associatedWindow->show();
-        }
+        associatedWindow->show();
         associatedWindow->raise();
         KWindowSystem::activateWindow(associatedWindow);
     } else {
-        // Work around https://bugreports.qt.io/browse/QTBUG-120316
-        if (auto *widgetwindow = static_cast<QWidgetWindow*>(associatedWindow->qt_metacast("QWidgetWindow"))) {
-            widgetwindow->widget()->hide();
-        } else {
-            associatedWindow->hide();
-        }
+        associatedWindow->hide();
     }
 }
 
